\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{umaeditorial}[2021/10/27 Editorial de la Universidad de Malaga]
\LoadClass[10pt]{book}

% ------------------------------------------------------

\RequirePackage{ifthen}

% ------------------------------------------------------

\newboolean{LIBRO}\setboolean{LIBRO}{false}
\newboolean{EBOOKPDF}\setboolean{EBOOKPDF}{false}

\newboolean{INGENIERIA}\setboolean{INGENIERIA}{false}
\newboolean{HUMANIDADES}\setboolean{HUMANIDADES}{false}
\newboolean{SALUD}\setboolean{SALUD}{false}

\newboolean{CROP}\setboolean{CROP}{false}

\newboolean{DistanciasEcuaciones}\setboolean{DistanciasEcuaciones}{true}

\newboolean{ENGLISH}\setboolean{ENGLISH}{false}

% ------------------------------------------------------

\DeclareOption{libro}{\setboolean{LIBRO}{true}}
\DeclareOption{ebookpdf}{
	\setboolean{EBOOKPDF}{true}
	\setboolean{LIBRO}{false}
	}

\DeclareOption{crop}{\setboolean{CROP}{true}}
\DeclareOption{nocrop}{\setboolean{CROP}{false}}

\DeclareOption{nomathskip}{\setboolean{DistanciasEcuaciones}{false}}

\DeclareOption{english}{\setboolean{ENGLISH}{true}}

\newcommand{\logoManuales}{LOGO_INGENIERIAS_Manuales_UMA}

\DeclareOption{ingenierias}{
	\setboolean{INGENIERIA}{true}
	\renewcommand{\logoManuales}{LOGO_INGENIERIAS_Manuales_UMA}
	}
\DeclareOption{humanidades}{
	\setboolean{HUMANIDADES}{true}
	\renewcommand{\logoManuales}{LOGO_HUMANIDADES_Manuales_UMA}	
	}
\DeclareOption{salud}{
	\setboolean{SALUD}{true}
	\renewcommand{\logoManuales}{LOGO_SALUD_Manuales_UMA}	
	}

% ------------------------------------------------------

\DeclareOption*{\ClassWarning{umaeditorial}{No es posible procesar la opci\'{o}n: ?\CurrentOption?}}

% ------------------------------------------------------

\ExecuteOptions{libro,nocrop,ingenierias}
\ProcessOptions\relax

\ifEBOOKPDF
	\setboolean{LIBRO}{false}
\fi

% ------------------------------------------------------

\RequirePackage{graphicx}
\RequirePackage{calc}

% ------------------------------------------------------

\ifthenelse{\boolean{LIBRO}}{%
  \renewcommand\maketitle{
  \IfFileExists{./configuraciones/referencias_cruzadas}
    {\input{./configuraciones/referencias_cruzadas}}
    {}
  \begin{titlepage}
  \setcounter{page}{3}
  \let\footnotesize\small
  \let\footnoterule\relax
  \let \footnote \thanks
  \null\vfil
  \begin{center}%
  \vskip 300\p@
  {\includegraphics[width=4.0cm]{./logos/\logoManuales}}
  \vskip -500\p@
	\rule{\textwidth}{1pt}\par
    \vskip 1.5em%
    {\Huge\bfseries \@title \par}%
    \vskip 1.5em%
	\rule{\textwidth}{1pt}\par    
    {\large
     \lineskip .75em%
	  \vskip 60\p@     
      \begin{tabular}[t]{c}%
        \@author\par
      \end{tabular}\par}%
	  \vskip 60\p@     
%    {\large \@date \par}%       % Set date in \large size.
%  \@thanks
  \vfil\null
  \end{center}\par
  \end{titlepage}%
  \setcounter{footnote}{0}%
  \global\let\thanks\relax
  \global\let\maketitle\relax
  \global\let\@thanks\@empty
  \global\let\@author\@empty
  \global\let\@date\@empty
  \global\let\@title\@empty
  \global\let\title\relax
  \global\let\author\relax
  \global\let\date\relax
  \global\let\and\relax
}}{}

\ifthenelse{\boolean{EBOOKPDF}}{%
  \renewcommand\maketitle{
  \IfFileExists{./configuraciones/referencias_cruzadas}
    {\input{./configuraciones/referencias_cruzadas}}
    {}
  \begin{titlepage}% Si la comentem compta com a p?gina del PDF
  \thispagestyle{plain}
  \let\footnotesize\small
  \let\footnoterule\relax
  \let \footnote \thanks
  \null\vfil
  \begin{center}%
  \vskip 355\p@
  \includegraphics[width=2.5cm]{./logos/\logoManuales}\\[-.25cm]
  \vskip -415\p@
	\rule{\textwidth}{1pt}\par
    \vskip 1.5em%
    {\Huge\bfseries \@title \par}%
    \vskip 1.5em%
	\rule{\textwidth}{1pt}\par    
    {\large
     \lineskip .75em%
	  \vskip 40\p@     
      \begin{tabular}[t]{c}%
        \@author\par
      \end{tabular}\par}%
	  \vskip 60\p@     
%    {\large \@date \par}%       % Set date in \large size.
%  \@thanks
  \vfil\null
  \end{center}\par
  \end{titlepage}%
  \setcounter{footnote}{0}%
  \setcounter{page}{2}
  \global\let\thanks\relax
  \global\let\maketitle\relax
  \global\let\@thanks\@empty
  \global\let\@author\@empty
  \global\let\@date\@empty
  \global\let\@title\@empty
  \global\let\title\relax
  \global\let\author\relax
  \global\let\date\relax
  \global\let\and\relax
  \clearpage
}}{}

% ---------------------------------------------------------------------
% Tipus de lletra

\ifLIBRO
	\renewcommand{\normalsize}{\fontsize{10.5pt}{12.5pt}\selectfont}
\fi

\ifEBOOKPDF
	\renewcommand{\normalsize}{\fontsize{12pt}{14pt}\selectfont}
\fi

% ---------------------------------------------------------------------

\renewcommand{\familydefault}{\sfdefault}
	
% ---------------------------------------------------------------------
% Format de pàgina

\RequirePackage{geometry}

\ifEBOOKPDF
	
	\geometry{
		twoside = false,
		body={4.75in,6.6in},
		hmarginratio=1:1,
		includeheadfoot,
		paperheight=7.60606060in,
   		paperwidth=5.8181818in,
   		vmargin={0cm},
   		headsep = 1.25cm,	
		footnotesep = 0.65cm,
		}

\else % libro

	\newlength{\anchoPublicacion}
	\setlength{\anchoPublicacion}{17cm}
	
	\newlength{\altoPublicacion}
	\setlength{\altoPublicacion}{24cm}
	
	\newlength{\margenVerticalSuperior}
	\setlength{\margenVerticalSuperior}{1.75cm}

	\newlength{\margenVerticalInferior}
	\setlength{\margenVerticalInferior}{1.75cm}
	
	\newlength{\margenInterior}
	\setlength{\margenInterior}{2.5cm}

	\geometry{ 
		twoside,
		vmargin = {\margenVerticalSuperior, \margenVerticalInferior}, 
		includehead, includefoot,
		left = \margenInterior,
		headheight = 0.5cm,	
		headsep = 0.75cm,
		footskip = 1.25cm,
		textwidth = 13cm, %totalheight = 20cm, % Caja de texto 13cm x 21 cm
		paperwidth = \anchoPublicacion, paperheight = \altoPublicacion,
		}

	% --------------------------------------------
	% Marcas de corte
	
	\ifCROP
		\usepackage[cam, a4, center, odd, noinfo]{crop}
	\fi

\fi


% ---------------------------------------------------------------------
% Cabeceras y pies de página

\RequirePackage{fancyhdr}
\pagestyle{fancy}

\renewcommand{\chaptermark}[1]{\markboth{\@chapapp\ \thechapter.\ #1}{}}
\renewcommand{\sectionmark}[1]{\markright{\thesection\ #1}{}}

\fancyhead{} % Borra la configuración de la cabecera
\fancyfoot{} % Borra la configuración del pie

\newlength{\myevenheadlinehoffset}
\newlength{\myevenheadtexthoffset}
\newlength{\myoddheadlinewidth}
\newlength{\myevenheadlinewidth}

%\setlength{\myevenheadlinehoffset}{-\margenInterior}
\setlength{\myevenheadlinehoffset}{0.0cm}
\setlength{\myevenheadtexthoffset}{0.0cm}

\setlength{\myoddheadlinewidth}{\textwidth}
\setlength{\myevenheadlinewidth}{\textwidth}
%\setlength{\myoddheadlinewidth}{\anchoPublicacion - \margenInterior} % Linea que llega al final
%\setlength{\myevenheadlinewidth}{\anchoPublicacion - \margenInterior} % Linea que llega al final

\RequirePackage{xcolor}

\definecolor{PANTONE_3125_C}{HTML}{00AEC7}
\definecolor{PANTONE_648_C}{HTML}{002E5D}
\definecolor{colorLetraEncabezado}{HTML}{FFFFFF}


%\newcommand{\elEncabezadoPaginaImpar}[1]{\markright{\thesection.\ #1}}

\newcommand{\encabezadoPaginaImpar}[1]{%
	\newcommand{\elEncabezadoPaginaImpar}{#1}
}


\ifEBOOKPDF

	\newlength{\hMargins}
	\setlength{\hMargins}{\paperwidth-\textwidth}
	\newlength{\hMargin}
	\setlength{\hMargin}{0.5\hMargins}
	\newlength{\posPagina}
	\setlength{\posPagina}{\textwidth + 0.5\hMargin}

	\RequirePackage{lastpage}
	\RequirePackage{tikz}
	
	\renewcommand{\chaptermark}[1]{\markboth{\thechapter.\ #1}{}}

	\fancyhf{} % 
	\fancyhead[L]{%
		\begin{tikzpicture}[overlay]
			\draw[fill=PANTONE_3125_C, draw=PANTONE_3125_C] (-\hMargin,2ex) rectangle ++(\paperwidth,-1.0cm);
			\draw[fill=PANTONE_648_C, draw=PANTONE_648_C,
			    yshift=-1cm] (-\hMargin,2ex) rectangle ++(\paperwidth,-0.01cm);
			\node[right] (leftMark) at (-0.75\hMargin,0) {\color{colorLetraEncabezado}\sffamily\mdseries\footnotesize\leftmark};
			\node[right] (rightMark) at (-0.5\hMargin,-2ex) {\color{colorLetraEncabezado}\sffamily\mdseries\scriptsize\rightmark};
			\node[] (thePage) at (\posPagina,-1ex) {\color{colorLetraEncabezado}\sffamily\small\thepage/\pageref*{LastPage}};
		\end{tikzpicture}
		}

	\fancypagestyle{plain}{% 
	\fancyhf{} % clear all header and footer fields 
	\fancyhead[L]{%
		\begin{tikzpicture}[overlay]
			\draw[fill=PANTONE_3125_C,draw=PANTONE_3125_C] (-\hMargin,2ex) rectangle ++(\paperwidth,-1.0cm);
			\draw[fill=PANTONE_648_C, draw=PANTONE_648_C,
			    yshift=-1cm] (-\hMargin,2ex) rectangle ++(\paperwidth,-0.01cm);
			\node[] (thePage) at (\posPagina,-1ex) {\color{colorLetraEncabezado}\sffamily\small\thepage/\pageref*{LastPage}};
		\end{tikzpicture}
		}}
	
	\renewcommand{\headrulewidth}{0.0pt}
	\renewcommand{\footrulewidth}{0.0pt}
	
	\renewcommand{\frontmatter}{}
	\renewcommand{\mainmatter}{}

\else % Libro

	\renewcommand{\chaptermark}[1]{\markboth{\thechapter.\ #1}{}}
%	\ifdefined\encabezadoPaginaImpar
%		\renewcommand{\sectionmark}[1]{\markright{\encabezadoPaginaImpar}}
%	\else
%		\renewcommand{\sectionmark}[1]{\markright{\thesection....\ #1}}
%	\fi
    
    
    \newlength{\myevenheadlinewidthX}
    \setlength{\myevenheadlinewidthX}{\myevenheadlinewidth+1em}

	\fancyhead[LE]{%
		\makebox[\textwidth][r]{\footnotesize\textbf{\thepage}\hfill\itshape\MakeUppercase{\leftmark}}
		\tikz[overlay]\draw[dotted,thin] (\myevenheadlinehoffset,0.25cm) -- (\textwidth,0.25cm);
		}
	\fancyhead[LO]{%
		\makebox[\textwidth][r]{\footnotesize\itshape\MakeUppercase{\rightmark}\hfill\textbf{\upshape\thepage}}
		\tikz[overlay]\draw[dotted,thin] (0cm,0.25cm) -- (\myoddheadlinewidth,0.25cm);
		}
		
	% Pie de la primera página del capítulo

	\fancypagestyle{plain}{% 
	    \fancyhf{}
		}

	\renewcommand{\headrulewidth}{0.0pt}
	\renewcommand{\footrulewidth}{0.0pt}

\fi



% ---------------------------------------------------------------------
% Formato de párrafo y maquetación


\setlength{\parskip}{2ex}
\setlength{\parindent}{0.4cm}
	
\newlength{\separaParrafos}
\setlength{\separaParrafos}{\parskip}
\newlength{\indentaParrafos}
\setlength{\indentaParrafos}{\parindent}

\linespread{1.0}

\setlength{\widowpenalty}{10000pt}
\setlength{\clubpenalty}{10000pt}

\raggedbottom

% ---------------------------------------------------------------------
% Color para los títulos en el formato 'ebookpdf'

\ifthenelse{\boolean{EBOOKPDF}}
    {
    \colorlet{colorTitulos}{PANTONE_648_C}
    \colorlet{colorNumCapitulo}{PANTONE_3125_C}    
    }
    {
    \colorlet{colorTitulos}{black}
    \colorlet{colorNumCapitulo}{black}
    }

% ---------------------------------------------------------------------
% Mojora los títulos de las figuras y tablas

\RequirePackage{caption}
\renewcommand{\captionlabelfont}{\color{colorTitulos}\fontsize{9}{11}\bfseries}
\renewcommand{\captionfont}{\color{colorTitulos}\fontsize{9}{11}\bfseries}

% ------------------------------------------------------------------------
% Formato de las secciones

\RequirePackage[
	raggedright,
	compact,
	nobottomtitles*, % Evita que los títulos se queden en la última línea de la página
	clearempty, % Modifica \cleardoublepage para que las hojas pares blancas estén vacías
	]{titlesec}

% ------------------------------------------------------------------------

\titleformat{\part}
	[display]
	{\thispagestyle{empty}\filcenter
	\tolerance=10000\hyphenpenalty=10000}
	{\color{colorTitulos}\fontsize{18}{20}\bfseries\partname\enspace\thepart}
	{1pc}
	{\color{colorTitulos}\fontsize{24}{30}\bfseries\uppercase}

% ------------------------------------------------------------------------

\ifEBOOKPDF

    % ------------------------------------------------------------------------

    \titleformat{\chapter}
    	[hang]
    	{\raggedright\tolerance=10000\hyphenpenalty=10000}
    	{\color{colorTitulos}\fontsize{18}{20}\bfseries\thechapter.}
    	{1em}
    	{\color{colorTitulos}\raggedright\fontsize{18}{24}\bfseries\uppercase}
    	[]

	% ------------------------------------------------------------------------
	
	\titleformat{\section}
		[hang]
		{\vspace{2ex}\raggedright\tolerance=10000\hyphenpenalty=10000}
		{\color{colorTitulos}\fontsize{13}{15}\bfseries\thesection.}
		{1em}
		{\color{colorTitulos}\fontsize{15}{15}\bfseries}
	
	% ------------------------------------------------------------------------
	
	\titleformat{\subsection}
		[hang]
		{\vspace{1.5ex}\raggedright\tolerance=10000\hyphenpenalty=10000}
		{\color{colorTitulos}\fontsize{12}{14}\bfseries\itshape\thesubsection.}
		{1em}
		{\color{colorTitulos}\fontsize{12}{14}\bfseries\itshape}
		[\vspace{-1ex}]


\else % Libro

    % ------------------------------------------------------------------------
    
    \titleformat{\chapter}
    	[hang]
    	{\raggedright\tolerance=10000\hyphenpenalty=10000}
    	{\fontsize{16}{20}\bfseries\thechapter.}
    	{1em}
    	{\raggedright\fontsize{16}{20}\bfseries\uppercase}
    	[]


	% ------------------------------------------------------------------------
	
	\titleformat{\section}
		[hang]
		{\vspace{2ex}\raggedright\tolerance=10000\hyphenpenalty=10000}
		{\fontsize{11}{14}\thesection.}
		{1em}
		{\fontsize{11}{14}\uppercase}
		[\vspace{1ex}]
	
	% ------------------------------------------------------------------------
	
	\titleformat{\subsection}
		[hang]
		{\vspace{1.5ex}\raggedright\tolerance=10000\hyphenpenalty=10000}
		{\fontsize{11}{14}\thesubsection.}
		{1em}
		{\fontsize{11}{14}}
		[\vspace{1ex}]
	
\fi


% ------------------------------------------------------------------------

\titleformat{\subsubsection}
	[hang]
	{\vspace{1.5ex}\raggedright\tolerance=10000\hyphenpenalty=10000}
	{\color{colorTitulos}\fontsize{11}{14}\itshape\thesubsubsection}
	{1em}
	{\color{colorTitulos}\fontsize{11}{14}\itshape}
	[\vspace{-1ex}]

% -------------------------------------------------------
% Para controlar la numeración y formato de la tabla de contenidos, lista de figuras y tablas

\setcounter{tocdepth}{1}

\RequirePackage[titles]{tocloft}

\renewcommand{\cftchapaftersnum}{}

\renewcommand{\cftsecfont}{\small}
\renewcommand{\cftsecpagefont}{\small}
\renewcommand{\cftsecaftersnum}{}

\renewcommand{\cftfigfont}{\small}
\renewcommand{\cftfigpagefont}{\small}

\renewcommand{\cfttabfont}{\small}
\renewcommand{\cfttabpagefont}{\small}

% ------------------------------------------------------------------------
% ------------------------------------------------------------------------
% ------------------------------------------------------------------------

\RequirePackage{enumitem}
\setlist[1]{partopsep=-1ex,parsep=\parskip,itemsep=0\parskip}
\setlist[2]{partopsep=-1ex,parsep=\parskip,itemsep=0\parskip}

% ------------------------------------------------------------------------
% ------------------------------------------------------------------------
% ------------------------------------------------------------------------

\AtBeginDocument
	{
	\ifdefined\elEncabezadoPaginaImpar
		\renewcommand{\sectionmark}[1]{\markright{\elEncabezadoPaginaImpar}}
	\else
		\renewcommand{\sectionmark}[1]{\markright{\thesection.\ #1}}
	\fi
	}

\RequirePackage{mathtools}

\ifDistanciasEcuaciones
\AtBeginDocument
	{
	% ---------------------------------------------------
	% Distancias de las ecuaciones al texto
	
	% Para ecuaciones en una sola línea
	\abovedisplayshortskip = -1.0ex plus 0ex minus 0.25ex
	\belowdisplayshortskip = 2.0ex plus 1ex minus 0.0ex
	
	% Para ecuaciones en varias líneas
	\abovedisplayskip = -1.0ex plus 0ex minus 0.25ex
	\belowdisplayskip = 2.0ex plus 1ex minus 0.0ex
	}
\fi

% ------------------------------------------------------------------------
% ------------------------------------------------------------------------
% ------------------------------------------------------------------------
